@@ -89,7 +89,7 @@ class FlowApiWrapper:
             cur_node = self._nodes[self.node_id]
         else:
             logger.error(
-                f"No {self.node_type} node with id({self.node_id}) found, exiting..."
+                f"Could not to find node({self.node_type}) with id({self.node_id}), exiting..."
             )
             return None
         logger.info(f"Node info: {cur_node}")
